@@ -9,7 +9,7 @@ use WebService::TWFY::Response ;
 use LWP::UserAgent ;
 
 our @ISA = qw( LWP::UserAgent ) ;
-our $VERSION = 0.07 ;
+our $VERSION = 0.01 ;
 
 =head1 NAME
 
@@ -17,7 +17,7 @@ WebService::TWFY::API - API interface for TheyWorkForYou.com
 
 =head1 VERSION
 
-Version 0.07
+Version 0.01  
 
 =cut
 
@@ -25,8 +25,7 @@ Version 0.07
 
   use WebService::TWFY::API ;
   
-  my $rh = { key => 'ABC123' }; 
-  my $api = WebService::TWFY::API->new( $rh ) ;
+  my $api = new WebService::TWFY::API ;
 
   my $rv = $api->query ( 'getConstituency', { 'postcode' => 'W128JL'
                                               'output'   => 'xml',
@@ -56,13 +55,8 @@ the API. However, it helps them track and monitor usage of the API service from
 
 The following constructor method creates C<WebService::TWFY::API> object and returns it.
 
-  my $rh = { key => 'ABC123' };
-
-  my $api = WebService::TWFY::API->new( $rh ) ;
-
-The API now requires a key, you can obtain one at L<http://www.theyworkforyou.com/api/key>.
-The key above will not work, its only used as an example.
-
+  my $api = new WebService::TWFY::API ;
+  
 In future versions, if needed, it will support specifying the version of the API you wish to use.
 
 =item C<execute_query>
@@ -121,18 +115,16 @@ Please feel free to send any bug reports and suggestions to my email listed belo
 
 For more information and useless facts on my life, you can also check my blog:
 
-  http://ffffruit.com/
+  http://idaru.blogspot.com/
+
 
 =head1 AUTHOR
 
     Spiros Denaxas
     CPAN ID: SDEN
+    Lokku Ltd
     s [dot] denaxas [@] gmail [dot]com
-    http://ffffruit.com
-
-=head1 SOURCE CODE
-
-The source code for his module is now on github L<https://github.com/spiros/WebService-TWFY-API>
+    http://idaru.blogspot.com
 
 =head1 COPYRIGHT
 
@@ -151,11 +143,6 @@ C<WebService::TWFY::Request>, C<WebService::TWFY::Response>, L<http://www.theywo
 
 sub new {
     my $class = shift ;
-    my $rh    = shift;
-    
-    unless ( defined $rh->{key} ) {
-       die "The API requires a key. You can obtain one at http://www.theyworkforyou.com/api/key";
-    }
     
     # Please do not change the following user agent parameter.
     # It does not provide TheyWorkForYou.com with any personal information
@@ -167,8 +154,6 @@ sub new {
     
     bless $self, $class ;
     
-    $self->{'_api_key'} = $rh->{'key'};
-    
     return $self ;
 }
 
@@ -179,8 +164,6 @@ sub query {
   return unless ( (defined $function) and (defined $rh_args) ) ;
   return unless ref $rh_args eq 'HASH' ;
   
-  $rh_args->{key} = $self->{_api_key};
-  
   my $query = new WebService::TWFY::Request ( $function, $rh_args ) ;
   
   if ( defined $query ) {
